@@ -1,6 +1,6 @@
 -- |
 -- Module      :  Control.Applicative.Combinators
--- Copyright   :  © 2017–2018 Mark Karpov
+-- Copyright   :  © 2017–2019 Mark Karpov
 -- License     :  BSD 3 clause
 --
 -- Maintainer  :  Mark Karpov <markkarpov92@gmail.com>
@@ -43,7 +43,6 @@
 -- composite parsers in @try@ to achieve correct behavior.
 
 {-# LANGUAGE BangPatterns #-}
-{-# LANGUAGE CPP          #-}
 
 module Control.Applicative.Combinators
   ( -- * Re-exports from "Control.Applicative"
@@ -81,13 +80,8 @@ module Control.Applicative.Combinators
 where
 
 import Control.Applicative
-import Data.Foldable
-
-#if MIN_VERSION_base(4,9,0)
 import Control.Monad (replicateM, replicateM_)
-#elif !MIN_VERSION_base(4,8,0)
-import Data.Traversable (sequenceA)
-#endif
+import Data.Foldable
 
 ----------------------------------------------------------------------------
 -- Re-exports from "Control.Applicative"
@@ -158,11 +152,7 @@ choice = asum
 -- See also: 'skipCount', 'count''.
 
 count :: Applicative m => Int -> m a -> m [a]
-#if MIN_VERSION_base(4,9,0)
 count = replicateM
-#else
-count n p = sequenceA (replicate n p)
-#endif
 {-# INLINE count #-}
 
 -- | @'count'' m n p@ parses from @m@ to @n@ occurrences of @p@. If @n@ is
@@ -300,11 +290,7 @@ skipSome p = p *> skipMany p
 -- @since 0.3.0
 
 skipCount :: Applicative m => Int -> m a -> m ()
-#if MIN_VERSION_base(4,9,0)
 skipCount = replicateM_
-#else
-skipCount n p = sequenceA_ (replicate n p)
-#endif
 {-# INLINE skipCount #-}
 
 -- | @'skipManyTill' p end@ applies the parser @p@ /zero/ or more times
