@@ -1,6 +1,6 @@
 -- |
 -- Module      :  Control.Applicative.Permutations
--- Copyright   :  © 2017–2018 Mark Karpov
+-- Copyright   :  © 2017–2019 Alex Washburn
 -- License     :  BSD 3 clause
 --
 -- Maintainer  :  Mark Karpov <markkarpov92@gmail.com>
@@ -40,6 +40,8 @@
 --
 -- @since 0.2.0
 
+{-# LANGUAGE CPP #-}
+
 module Control.Applicative.Permutations
   ( -- ** Permutation type
     Permutation
@@ -55,7 +57,7 @@ import Control.Applicative
 
 -- | An 'Applicative' wrapper-type for constructing permutation parsers.
 
-data Permutation m a = P (Maybe a) (m (Permutation m a))
+data Permutation m a = P !(Maybe a) (m (Permutation m a))
 
 instance Functor m => Functor (Permutation m) where
   fmap f (P v p) = P (f <$> v) (fmap f <$> p)
@@ -66,6 +68,12 @@ instance Alternative m => Applicative (Permutation m) where
     where
       lhsAlt = (<*> rhs) <$> v
       rhsAlt = (lhs <*>) <$> w
+#if MIN_VERSION_base(4,10,0)
+  liftA2 f lhs@(P x v) rhs@(P y w) = P (liftA2 f x y) (lhsAlt <|> rhsAlt)
+    where
+      lhsAlt = (\p -> liftA2 f p rhs) <$> v
+      rhsAlt = liftA2 f lhs <$> w
+#endif
 
 -- | \"Unlifts\" a permutation parser into a parser to be evaluated.
 
