@@ -1,6 +1,6 @@
 -- |
 -- Module      :  Control.Monad.Combinators
--- Copyright   :  © 2017–2018 Mark Karpov
+-- Copyright   :  © 2017–2019 Mark Karpov
 -- License     :  BSD 3 clause
 --
 -- Maintainer  :  Mark Karpov <markkarpov92@gmail.com>
@@ -17,7 +17,6 @@
 -- @since 0.4.0
 
 {-# LANGUAGE BangPatterns #-}
-{-# LANGUAGE CPP          #-}
 
 module Control.Monad.Combinators
   ( -- * Re-exports from "Control.Applicative"
@@ -88,11 +87,11 @@ import qualified Control.Applicative.Combinators as C
 -- See also: 'skipCount', 'count''.
 
 count :: Monad m => Int -> m a -> m [a]
-count n' p = liftM ($ []) (go id n')
+count n' p = go id n'
   where
     go f !n =
       if n <= 0
-        then return f
+        then return (f [])
         else do
           x <- p
           go (f . (x:)) (n - 1)
@@ -110,7 +109,7 @@ count n' p = liftM ($ []) (go id n')
 count' :: MonadPlus m => Int -> Int -> m a -> m [a]
 count' m' n' p =
   if n' > 0 && n' >= m'
-    then liftM ($ []) (gom id m')
+    then gom id m'
     else return []
   where
     gom f !m =
@@ -124,9 +123,9 @@ count' m' n' p =
         then do
           r <- optional p
           case r of
-            Nothing -> return f
+            Nothing -> return (f [])
             Just  x -> god (f . (x:)) (d - 1)
-        else return f
+        else return (f [])
 {-# INLINE count' #-}
 
 -- | @'endBy' p sep@ parses /zero/ or more occurrences of @p@, separated and
@@ -151,12 +150,12 @@ endBy1 p sep = some (p >>= \x -> re x sep)
 -- > identifier = (:) <$> letter <*> many (alphaNumChar <|> char '_')
 
 many :: MonadPlus m => m a -> m [a]
-many p = liftM ($ []) (go id)
+many p = go id
   where
     go f = do
       r <- optional p
       case r of
-        Nothing -> return f
+        Nothing -> return (f [])
         Just  x -> go (f . (x:))
 {-# INLINE many #-}
 
@@ -166,12 +165,12 @@ many p = liftM ($ []) (go id)
 -- See also: 'skipMany', 'skipManyTill'.
 
 manyTill :: MonadPlus m => m a -> m end -> m [a]
-manyTill p end = liftM ($ []) (go id)
+manyTill p end = go id
   where
     go f = do
       done <- option False (re True end)
       if done
-        then return f
+        then return (f [])
         else do
           x <- p
           go (f . (x:))
@@ -205,7 +204,7 @@ sepBy p sep = do
   r <- optional p
   case r of
     Nothing -> return []
-    Just  x -> liftM (x:) (many (sep >> p))
+    Just  x -> (x:) <$> many (sep >> p)
 {-# INLINE sepBy #-}
 
 -- | @'sepBy1' p sep@ parses /one/ or more occurrences of @p@, separated by
@@ -214,24 +213,24 @@ sepBy p sep = do
 sepBy1 :: MonadPlus m => m a -> m sep -> m [a]
 sepBy1 p sep = do
   x <- p
-  liftM (x:) (many (sep >> p))
+  (x:) <$> many (sep >> p)
 {-# INLINE sepBy1 #-}
 
 -- | @'sepEndBy' p sep@ parses /zero/ or more occurrences of @p@, separated
 -- and optionally ended by @sep@. Returns a list of values returned by @p@.
 
 sepEndBy :: MonadPlus m => m a -> m sep -> m [a]
-sepEndBy p sep = liftM ($ []) (go id)
+sepEndBy p sep = go id
   where
     go f = do
       r <- optional p
       case r of
-        Nothing -> return f
+        Nothing -> return (f [])
         Just  x -> do
           more <- option False (re True sep)
           if more
             then go (f . (x:))
-            else return (f . (x:))
+            else return (f [x])
 {-# INLINE sepEndBy #-}
 
 -- | @'sepEndBy1' p sep@ parses /one/ or more occurrences of @p@, separated
@@ -242,7 +241,7 @@ sepEndBy1 p sep = do
   x <- p
   more <- option False (re True sep)
   if more
-    then liftM (x:) (sepEndBy p sep)
+    then (x:) <$> sepEndBy p sep
     else return [x]
 {-# INLINE sepEndBy1 #-}
 
@@ -312,7 +311,7 @@ skipSomeTill p end = p >> skipManyTill p end
 -- Compat helpers (for older GHCs)
 
 re :: Monad m => a -> m b -> m a
-re x = liftM (const x)
+re x = fmap (const x)
 {-# INLINE re #-}
 
 option :: MonadPlus m => a -> m a -> m a
@@ -320,5 +319,5 @@ option x p = p `mplus` return x
 {-# INLINE option #-}
 
 optional :: MonadPlus m => m a -> m (Maybe a)
-optional p = liftM Just p `mplus` return Nothing
+optional p = fmap Just p `mplus` return Nothing
 {-# INLINE optional #-}
